==> resin-4.0.59-src.tar.gz: resin-4.0.59/modules/resin/src/com/caucho/env/lock/SingleLockManager.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.env.lock;

import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.locks.Lock;


/**
 * Manages the distributed lock
 */
public class SingleLockManager extends AbstractLockManager {
  private ConcurrentHashMap<String,SingleLock> _lockMap
    = new ConcurrentHashMap<String,SingleLock>();

  public SingleLockManager()
  {
  }

  @Override
  public Lock getOrCreateLock(String name)
  {
    SingleLock lock = _lockMap.get(name);

    if (lock == null) {
      lock = new SingleLock(name);

      SingleLock oldLock = _lockMap.putIfAbsent(name, lock);

      if (oldLock != null)
        lock = oldLock;
    }

    return lock;
  }
}

==> resin-4.0.66-src.tar.gz: resin-4.0.66/modules/resin/src/com/caucho/env/lock/SingleLockManager.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.env.lock;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.locks.Lock;


/**
 * Manages the distributed lock
 */
public class SingleLockManager extends AbstractLockManager {
  private Map<String,SingleLock> _lockMap
    = new ConcurrentHashMap<String,SingleLock>();

  public SingleLockManager()
  {
  }

  @Override
  public Lock getOrCreateLock(String name)
  {
    SingleLock lock = _lockMap.get(name);

    if (lock == null) {
      lock = new SingleLock(name);

      SingleLock oldLock = _lockMap.putIfAbsent(name, lock);

      if (oldLock != null)
        lock = oldLock;
    }

    return lock;
  }
}
